==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/it/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Un utente ha annullato una richiesta di articolo sul sito web',
    'a_user_requested' => 'Un utente ha richiesto un elemento tramite il sito web',
    'accessory_name' => 'Nome accessorio:',
    'additional_notes' => 'Note aggiuntive:',
    'admin_has_created' => 'Un amministratore ha creato un account per il tuo sito web: web.',
    'asset' => 'Bene:',
    'asset_name' => 'Nome del bene:',
    'asset_requested' => 'Bene richiesto',
    'asset_tag' => 'Tag del bene:',
    'assigned_to' => 'Assegnato a',
    'best_regards' => 'Cordiali saluti,',
    'canceled' => 'Cancellato:',
    'checkin_date' => 'Data di iscrizione:',
    'checkout_date' => 'Data di partenza:',
    'click_to_confirm' => 'Per confermare, clicca sul seguente link: account web:',
    'click_on_the_link_accessory' => 'Fare clic sul collegamento in basso per confermare di aver ricevuto l\'accessorio.',
    'click_on_the_link_asset' => 'Fai clic sul link in basso per confermare di aver ricevuto l\'asset.',
    'Confirm_Asset_Checkin' => 'Conferma checkin asset',
    'Confirm_Accessory_Checkin' => 'Conferma checkin accessorio',
    'Confirm_accessory_delivery' => 'Conferma assegnazione accessorio',
    'Confirm_license_delivery' => 'Conferma assegnazione licenza',
    'Confirm_asset_delivery' => 'Conferma assegnazione asset',
    'Confirm_consumable_delivery' => 'Confermar consegna consumabile',
    'current_QTY' => 'Corrente QTY',
    'Days' => 'giorni',
    'days' => 'giorni',
    'expecting_checkin_date' => 'Data di verifica prevista:',
    'expires' => 'Scade',
    'Expiring_Assets_Report' => 'Termine di scadenza dell\'attivo.',
    'Expiring_Licenses_Report' => 'Termine di licenza scadente.',
    'hello' => 'Ciao',
    'hi' => 'Ciao',
    'i_have_read' => 'Ho letto e accetto i termini di utilizzo e ho ricevuto questo elemento.',
    'item' => 'Articolo:',
    'Item_Request_Canceled' => 'Richiesta dell\'oggetto annullato',
    'Item_Requested' => 'Item richiesto',
    'link_to_update_password' => 'Fai clic sul seguente collegamento per aggiornare la tua password: web:',
    'login_first_admin' => 'Accedi alla nuova installazione di Snipe-IT utilizzando le seguenti credenziali:',
    'login' => 'Accesso:',
    'Low_Inventory_Report' => 'Rapporto di inventario basso',
    'min_QTY' => 'Min QTY',
    'name' => 'Nome',
    'new_item_checked' => 'Un nuovo elemento è stato controllato sotto il tuo nome, i dettagli sono sotto.',
    'password' => 'Parola d\'ordine:',
    'password_reset' => 'Reimpostazione della password',

    'read_the_terms' => 'Leggi i termini di utilizzo qui sotto.',
    'read_the_terms_and_click' => 'Leggi i termini di utilizzo qui sotto e fai clic sul link in basso per confermare di leggere e accettare i termini di utilizzo e di aver ricevuto l\'asset.',
    'requested' => 'richiesta:',
    'reset_link' => 'La tua password ripristina il collegamento',
    'reset_password' => 'Clicca qui per ripristinare la tua password:',
    'serial' => 'Seriale',
    'supplier' => 'Fornitore',
    'tag' => 'Etichetta',
    'test_email' => 'Test Email da Snipe-IT',
    'test_mail_text' => 'Questo è un test del Snipe-IT Asset Management System. Se hai questo, la posta è in funzione :)',
    'the_following_item' => 'La seguente voce è stata selezionata:',
    'low_inventory_alert' => 'C\'è :count elemento che è al di sotto del livello di scorta minima o lo sarà a breve. |Ci sono :count elementi che sono al di sotto del livello di scorta minima o lo saranno a breve.',
    'assets_warrantee_alert' => 'C\'è :count bene con una garanzia in scadenza tra :threshold giorni.|Ci sono :count beni che hanno le garanzie in scandenza tra :threshold giorni.',
    'license_expiring_alert' => 'Tra :threshold giorni sta per scadere :count licenza. |Tra :threshold giorni stanno per scadere :count licenze.',
    'to_reset' => 'Per reimpostare la tua password web, compila questo modulo:',
    'type' => 'Tipo',
    'upcoming-audits' => 'C\'è :count asset in programma per la revisione entro :threshold giorni.|Ci sono :count asset in programma per la revisione entro :threshold giorni.',
    'user' => 'Utente',
    'username' => 'Nome utente',
    'welcome' => 'Benvenuto: nome',
    'welcome_to' => 'Benvenuti in: web!',
    'your_credentials' => 'Le tue credenziali Snipe-IT',
    'Accessory_Checkin_Notification' => 'Checkin accessorio avvenuto',
    'Asset_Checkin_Notification' => 'Checkin asset avvenuto',
    'License_Checkin_Notification' => 'Checkin licenza avvenuto',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'Un asset assegnato a te deve essere ricontrollato il :date',
    'your_assets' => 'Visualizza i tuoi assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/it/mail.php <==
<?php

return [
    'a_user_canceled' => 'Un utente ha annullato una richiesta di articolo sul sito web',
    'a_user_requested' => 'Un utente ha richiesto un elemento tramite il sito web',
    'accessory_name' => 'Nome accessorio:',
    'additional_notes' => 'Note aggiuntive:',
    'admin_has_created' => 'Un amministratore ha creato un account per il tuo sito web: web.',
    'asset' => 'Bene:',
    'asset_name' => 'Nome del bene:',
    'asset_requested' => 'Bene richiesto',
    'asset_tag' => 'Etichetta del bene',
    'assigned_to' => 'Assegnato a',
    'best_regards' => 'Cordiali saluti,',
    'canceled' => 'Cancellato:',
    'checkin_date' => 'Data di iscrizione:',
    'checkout_date' => 'Data di partenza:',
    'click_to_confirm' => 'Per confermare, clicca sul seguente link: account web:',
    'click_on_the_link_accessory' => 'Fare clic sul collegamento in basso per confermare di aver ricevuto l\'accessorio.',
    'click_on_the_link_asset' => 'Fai clic sul link in basso per confermare di aver ricevuto l\'asset.',
    'Confirm_Asset_Checkin' => 'Conferma checkin asset',
    'Confirm_Accessory_Checkin' => 'Conferma checkin accessorio',
    'Confirm_accessory_delivery' => 'Conferma assegnazione accessorio',
    'Confirm_license_delivery' => 'Conferma assegnazione licenza',
    'Confirm_asset_delivery' => 'Conferma assegnazione asset',
    'Confirm_consumable_delivery' => 'Confermar consegna consumabile',
    'current_QTY' => 'Corrente QTY',
    'Days' => 'giorni',
    'days' => 'giorni',
    'expecting_checkin_date' => 'Data di verifica prevista:',
    'expires' => 'Scade',
    'Expiring_Assets_Report' => 'Termine di scadenza dell\'attivo.',
    'Expiring_Licenses_Report' => 'Termine di licenza scadente.',
    'hello' => 'Ciao',
    'hi' => 'Ciao',
    'i_have_read' => 'Ho letto e accetto i termini di utilizzo e ho ricevuto questo elemento.',
    'item' => 'Articolo:',
    'Item_Request_Canceled' => 'Richiesta dell\'oggetto annullato',
    'Item_Requested' => 'Item richiesto',
    'link_to_update_password' => 'Fai clic sul seguente collegamento per aggiornare la tua password: web:',
    'login_first_admin' => 'Accedi alla nuova installazione di Snipe-IT utilizzando le seguenti credenziali:',
    'login' => 'Accesso:',
    'Low_Inventory_Report' => 'Rapporto di inventario basso',
    'min_QTY' => 'Min QTY',
    'name' => 'Nome',
    'new_item_checked' => 'Un nuovo elemento è stato controllato sotto il tuo nome, i dettagli sono sotto.',
    'password' => 'Parola d\'ordine:',
    'password_reset' => 'Reimpostazione della password',

    'read_the_terms' => 'Leggi i termini di utilizzo qui sotto.',
    'read_the_terms_and_click' => 'Leggi i termini di utilizzo qui sotto e fai clic sul link in basso per confermare di leggere e accettare i termini di utilizzo e di aver ricevuto l\'asset.',
    'requested' => 'richiesta:',
    'reset_link' => 'La tua password ripristina il collegamento',
    'reset_password' => 'Clicca qui per ripristinare la tua password:',
    'serial' => 'Seriale',
    'supplier' => 'Fornitore',
    'tag' => 'Etichetta',
    'test_email' => 'Test Email da Snipe-IT',
    'test_mail_text' => 'Questo è un test del Snipe-IT Asset Management System. Se hai questo, la posta è in funzione :)',
    'the_following_item' => 'La seguente voce è stata selezionata:',
    'low_inventory_alert' => 'C\'è :count elemento che è al di sotto del livello di scorta minima o lo sarà a breve. |Ci sono :count elementi che sono al di sotto del livello di scorta minima o lo saranno a breve.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Tra :threshold giorni sta per scadere :count licenza. |Tra :threshold giorni stanno per scadere :count licenze.',
    'to_reset' => 'Per reimpostare la tua password web, compila questo modulo:',
    'type' => 'Tipo',
    'upcoming-audits' => 'C\'è :count asset in programma per la revisione entro :threshold giorni.|Ci sono :count asset in programma per la revisione entro :threshold giorni.',
    'user' => 'Utente',
    'username' => 'Nome utente',
    'welcome' => 'Benvenuto: nome',
    'welcome_to' => 'Benvenuti in: web!',
    'your_credentials' => 'Le tue credenziali Snipe-IT',
    'Accessory_Checkin_Notification' => 'Checkin accessorio avvenuto',
    'Asset_Checkin_Notification' => 'Checkin asset avvenuto',
    'License_Checkin_Notification' => 'Checkin licenza avvenuto',
    'Expected_Checkin_Report' => 'Rapporto restituzione attesa del bene',
    'Expected_Checkin_Notification' => 'Promemoria: scadenza riconsegna :name in avvicinamento',
    'Expected_Checkin_Date' => 'Un asset assegnato a te deve essere ricontrollato il :date',
    'your_assets' => 'Visualizza i tuoi assets',
];
